(async-test description & cmds)Defines an async test. On Clojure, wraps all execution over a go-block.
On ClojureScript, wraps execution on a go-block and also sets the async
option. If the first argument of cmds is a map, it'll accept the following
keys:
:teardown - a sequence of commands that will tear down after the execution of every async test, both on success or on failure :timeout - the time that the async test will wait before timing out
Defines an async test. On Clojure, wraps all execution over a go-block. On ClojureScript, wraps execution on a go-block and also sets the `async` option. If the first argument of `cmds` is a map, it'll accept the following keys: :teardown - a sequence of commands that will tear down after the execution of every async test, both on success or on failure :timeout - the time that the async test will wait before timing out
(await! chan)(await-all! chans)(get-from-channel! cljs? chan)(promise-test description & cmds)(promise-test* prom done tear time)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |